@@ -151,13 +151,21 @@ class TestDXAppWizardAndRunAppLocally(DXTestCase):
         dxapp_json = json.load(open(os.path.join(appdir, 'dxapp.json')))
         self.assertEqual(dxapp_json.get('authorizedUsers'), [])
 
-    def test_dx_run_app_locally(self):
+    def test_dx_run_app_locally_interactively(self):
+        appdir = create_app_dir()
+        local_run = pexpect.spawn("dx-run-app-locally {} -iin1=8".format(appdir))
+        local_run.expect("Confirm")
+        local_run.sendline()
+        local_run.expect("App finished successfully")
+        local_run.expect("Final output: out1 = 140")
+        local_run.close()
+
+    def test_dx_run_app_locally_noninteractively(self):
         appdir = create_app_dir()
         output = check_output(['dx-run-app-locally', appdir, '-iin1=8'])
         print(output)
         self.assertIn("App finished successfully", output)
         self.assertIn("Final output: out1 = 140", output)
-        return appdir
 
     @unittest.skipUnless(testutil.TEST_RUN_JOBS,
                          'skipping test that would run jobs')
@@ -198,9 +206,10 @@ class TestDXAppWizardAndRunAppLocally(DXTestCase):
             "version": "0.0.1",
             "categories": [],
             "inputSpec": [
-                {"name": "required_file",
-                 "class": "file",
-                 "optional": False
+                {
+                    "name": "required_file",
+                    "class": "file",
+                    "optional": False
                 },
                 {
                     "name": "optional_file",
@@ -378,16 +387,20 @@ class TestDXBashHelpers(DXTestCase):
         dxpy.upload_string("ABCD", name="B.txt")
 
         # these should succeed
-        self.run_test_app_locally('basic',['-iseq1=A.txt', '-iseq2=B.txt',
-                                           '-iref=A.txt', '-iref=B.txt',
-                                           "-ivalue=5", '-iages=1'])
-        self.run_test_app_locally('basic',['-iseq1=A.txt', '-iseq2=B.txt', '-ibar=A.txt',
-                                           '-iref=A.txt', '-iref=B.txt',
-                                           "-ivalue=5", '-iages=1'])
+        self.run_test_app_locally('basic', ['-iseq1=A.txt', '-iseq2=B.txt',
+                                            '-iref=A.txt', '-iref=B.txt',
+                                            "-ivalue=5", '-iages=1'])
+        self.run_test_app_locally('basic', ['-iseq1=A.txt', '-iseq2=B.txt', '-ibar=A.txt',
+                                            '-iref=A.txt', '-iref=B.txt',
+                                            "-ivalue=5", '-iages=1'])
         self.run_test_app_locally('basic', ['-iseq1=A.txt', '-iseq2=B.txt',
                                             '-iref=A.txt', '-iref=B.txt', "-ivalue=5",
                                             '-iages=1', '-iages=11', '-iages=33'])
-        print("Done")
+
+        # check the except flags
+        self.run_test_app_locally('basic_except', ['-iseq1=A.txt', '-iseq2=B.txt',
+                                                   '-iref=A.txt', '-iref=B.txt', "-ivalue=5",
+                                                   '-iages=1', '-iages=11', '-iages=33'])
 
     def test_sub_jobs(self):
         '''  Tests a bash script that generates sub-jobs '''
@@ -395,14 +408,6 @@ class TestDXBashHelpers(DXTestCase):
         dxpy.upload_string("ABCD", name="B.txt")
         self.run_test_app_locally('with-subjobs', ["-ifiles=A.txt", "-ifiles=B.txt"])
 
-    def test_name_collision(self):
-        '''  Tests that name collisions are handled correctly. This is supposed to fail.'''
-        dxpy.upload_string("1234", name="A.txt")
-        with self.assertRaises(testutil.DXCalledProcessError):
-            self.run_test_app_locally('basic', ["-iseq1=A.txt", "-iseq2=A.txt",
-                                                '-iref=A.txt', '-iref=A.txt',
-                                                "-ivalue=5"])
-
 
 if __name__ == '__main__':
     unittest.main()
